==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesTpi.php <==
<?php
/** Tok Pisin (Tok Pisin)
 *
 * @ingroup Language
 * @file
 *
 * @author Wantok
 * @author Wytukaze
 * @author לערי ריינהארט
 */

$messages = array(
# User preference toggles
'tog-underline'               => 'Putim lain ananit long ol link:',
'tog-highlightbroken'         => 'Soim ol link long ol pes i no stap yet <a href="" class="new">olsem</a> (o: olsem<a href="" class="internal">?</a>).',
'tog-justify'                 => "Soim ol paragraf i pulmapim sipes long lephan i go long raithan (''justify'')",
'tog-hideminor'               => 'Noken soim ol liklik senis insait long ol nupela senis',
'tog-extendwatchlist'         => 'Larim lukautbuk i go longpela long soim olgeta senis',
'tog-usenewrc'                => 'Moa beta stail bilong nupela senis (i nidim JavaScript)',
'tog-numberheadings'          => 'Putim ol namba i go long wanwan hap bilong pes',
'tog-showtoolbar'             => 'Soim ol liklik link long wokim senis kwiktaim (i nidim JavaScript)',
'tog-editondblclick'          => 'Senisim pes taim yu paitim tupela taim kwiktaim (i nidim JavaScript)',
'tog-editsection'             => 'Soim ol [senisim] link long wanwan hap bilong ol pes',
'tog-editsectiononrightclick' => 'Senisim ol hap bilong pes taim yu paitim nem bilong hap<br />wantaim raithan-klik (i nidim Javascript)',
'tog-showtoc'                 => 'Soim ol nem bilong hap insait long liklik bokis, taim igat antap long 3 hap long pes',
'tog-rememberpassword'        => 'Holim nem bilong yusa bilong mi long dispela kompiuta',
'tog-editwidth'               => 'Larim bokis bilong senisim igo bikpela olgeta',
'tog-watchcreations'          => 'Putim ol nupela pes mi wokim long lukautbuk',
'tog-watchdefault'            => 'Putim ol pes mi senisim long lukautbuk bilong mi',
'tog-watchmoves'              => 'Putim ol pes mi surikim long lukautbuk bilong mi',
'tog-watchdeletion'           => 'Putim ol pes mi rausim long lukautbuk bilong mi',
'tog-minordefault'            => 'Makim ol senis mi wokim olsem ol i liklik, sapos mi no makim',
'tog-previewontop'            => 'Soim pes mi senisim (pastaim long raitim) antap long bokis bilong wokim senis',
'tog-previewonfirst'          => 'Soim pes mi senisim pastaim long raitim',
'tog-enotifwatchlistpages'    => 'Salim imel (e-mail) long mi taim wanpela pes mi lukautim i senis',
'tog-shownumberswatching'     => 'Soim hamas yusa i lukautim pes',
'tog-uselivepreview'          => 'Soim ol senis kwiktaim taim mi wokim (i nidim Javascript)',
'tog-watchlisthideown'        => 'Haitim ol senis mi wokim long lukautbuk bilong mi',
'tog-watchlisthidebots'       => 'Haitim ol senis ol bot i wokim long lukautbuk bilong mi',
'tog-watchlisthideminor'      => 'Haitim ol liklik senis long lukautbuk bilong mi',

'skinpreview' => '(pes mi senisim, pastaim long raitim)',

# Dates
'sunday'    => 'Sande',
'monday'    => 'Mande',
'tuesday'   => 'Tunde',
'wednesday' => 'Trinde',
'thursday'  => 'Fonde',
'friday'    => 'Fraide',
'saturday'  => 'Sarere',
'sun'       => 'San',
'mon'       => 'Man',
'tue'       => 'Tun',
'wed'       => 'Tri',
'thu'       => 'Fon',
'fri'       => 'Frai',
'sat'       => 'Sar',

# Categories related messages
'pagecategories'        => '{{PLURAL:$1|Grup|Ol grup}}',
'category_header'       => 'Ol pes insait long grup "$1"',
'subcategories'         => 'Ol grup insait long grup',
'category-media-header' => 'Ol media (olsem piksa) insait long grup "$1"',
'category-empty'        => "''Dispela grup i no gat wanpela pes o media (olsem piksa) insait long en nau.''",

'newwindow'      => '(bai kamap long nupela windo)',
'cancel'         => 'Toromwe senis',
'qbfind'         => 'Painim',
'qbedit'         => 'Senisim',
'qbspecialpages' => 'Ol sipesol pes',
'mytalk'         => 'Toktok bilong mi',
'navigation'     => 'Ol bikpela pes',

'help'             => 'Halivim mi',
'search'           => 'Painim',
'searchbutton'     => 'Painim',
'history'          => 'Ol senis long dispela pes',
'history_short'    => 'Ol senis',
'edit'             => 'Senisim',
'delete'           => 'Rausim',
'deletethispage'   => 'Rausim dispela pes',
'talkpagelinktext' => 'Toktok',
'talk'             => 'Toktok',
'toolbox'          => 'Sipesol bokis',
'categorypage'     => 'Lukim pes bilong grup',
'otherlanguages'   => 'Long ol narapela tokples',
'jumptonavigation' => 'ol bikpela pes',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Karen afeas',
'currentevents-url'    => 'Project:Karen afeas',
'edithelp'             => 'Halivim mi long pasin bilong wokim senis',
'mainpage'             => 'Fran Pes',
'mainpage-description' => 'Fran Pes',
'portal'               => 'Bung ples',
'portal-url'           => 'Project:Bung ples',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Stori',
'nstab-user'      => 'Pes bilong yusa',
'nstab-media'     => 'Media pes',
'nstab-special'   => 'Sipesol',
'nstab-mediawiki' => 'Toksave',
'nstab-category'  => 'Grup',

# Login and logout pages
'logout'     => 'Logaut',
'userlogout' => 'Logaut',

# Edit pages
'summary'           => 'Liklik toksave bilong senis',
'subject'           => 'Nem bilong pes (o hap bilong pes)',
'minoredit'         => 'Dispela emi liklik senis',
'watchthis'         => 'Putim dispela pes long lukautbuk bilong mi',
'savearticle'       => 'Raitim pes',
'preview'           => 'Pes wantaim senis (pastaim long raitim)',
'showpreview'       => 'Soim pes wantaim senis (pastaim long raitim)',
'showlivepreview'   => 'Soim senis kwiktaim taim mi wokim (pastaim long raitim)',
'showdiff'          => 'Soim ol senis',
'summary-preview'   => 'Toksave bilong senis bai luk olsem',
'subject-preview'   => 'Nem bilong pes (o hap bilong pes) bai olsem',
'copyrightwarning'  => 'Toksave: olgeta senis yu wokim long long {{SITENAME}} bai stap ananit long tokorait $2 (lukim $1 long painimaut moa long dispela). Sapos yu no laikim narapela manmeri long senisim olgeta, o salim dispela i go long ol kainkain hap, noken raitim long hia.<br />
Na tu yu tok tru nau olsem yu raitim dispela yu yet, o yu kisim long wanpela hap we lo i tok olsem i orait long kisim (Tok Inglis: <i>public domain</i>).
<strong>YU NOKEN RAITIM WANPELA SAMTING SAPOS YU NO WOKIM YU YET, O YU KISIM TOKORAIT LONG PUTIM LONG HIA!</strong>',
'copyrightwarning2' => 'Toksave: olgeta senis yu wokim long long {{SITENAME}} bai inap senis o raus long han bilong ol narapela manmeri. Sapos yu no laikim narapela manmeri long senisim olgeta samting yu raitim, o salim dispela i go long ol kainkain hap, noken raitim long hia.<br />
Na tu yu tok tru nau olsem yu raitim dispela yu yet, o yu kisim long wanpela hap we lo i tok olsem i orait long kisim (Tok Inglis: <i>public domain</i>). Lukim $1 long painimaut moa long dispela.<br />
<strong>YU NOKEN RAITIM WANPELA SAMTING IGAT COPYRIGHT LONG EN (NARAPELA MANMERI I RAITIM)!</strong>',
'templatesused'     => 'Dispela pes i yusim ol templet:',

# Preferences page
'mypreferences'   => 'Ol laik bilong mi',
'prefs-edits'     => 'Hamas senis:',
'prefs-rc'        => 'Nupela senis',
'prefs-watchlist' => 'Lukautbuk',

# Recent changes
'recentchanges'     => 'Nupela senis',
'rcnote'            => "Ananit yu lukim '''$1 senis''' long '''$2 de''' igo pinis, na i olsem long $3.",
'rc_categories'     => 'Soim ol senis insait long ol dispela grup tasol (raitim wantaim "|" namel long wanwan)',
'rc_categories_any' => 'Olgeta',

# Recent changes linked
'recentchangeslinked' => 'Ol senis klostu',

# Upload
'upload' => 'Salim media fail',

# Random page
'randompage' => 'Soim wanpela pes',

# Miscellaneous special pages
'ncategories'             => '$1 {{PLURAL:$1|grup|grup}}',
'nmembers'                => '$1 {{PLURAL:$1|memba|memba}}',
'uncategorizedpages'      => 'Ol pes i no stap insait long grup',
'uncategorizedcategories' => 'Ol grup i no stap insait long grup',
'uncategorizedimages'     => 'Ol piksa i no stap insait long grup',
'uncategorizedtemplates'  => 'Ol templet i no stap insait long grup',
'unusedcategories'        => 'Ol grup i no gat samting insait long ol',
'unusedimages'            => 'Ol media (olsem piksa) i no gat wanpela pes i soim ol',
'wantedcategories'        => 'Ol grup i no stap yet tasol igat link i kam long ol',
'wantedpages'             => 'Ol pes i no stap yet tasol igat link i kam long ol',
'mostlinked'              => 'Ol pes i gat planti link i kam long ol',
'mostlinkedcategories'    => 'Ol grup igat planti link i kam long ol',
'mostlinkedtemplates'     => 'Ol templet igat planti link i kam long ol',
'mostcategories'          => 'Ol pes bilong buk istap insait long planti grup',
'move'                    => 'Surikim',
'movethispage'            => 'Surikim dispela pes',
'unusedcategoriestext'    => 'Ol dispela grup istap yet, tasol i no gat wanpela pes o grup i stap insait long ol.',

# Special:AllPages
'allpages' => 'Olgeta pes',

# Special:Categories
'categories'         => 'Ol grup',
'categoriespagetext' => 'Ol dispela grup istap.',

# Watchlist
'watchlist'            => 'Lukautbuk bilong mi',
'mywatchlist'          => 'Lukautbuk bilong mi',
'watchlistfor'         => "(bilong '''$1''')",
'nowatchlist'          => 'Nogat wanpela samting istap long lukautbuk bilong yu.',
'watchlistanontext'    => 'Yu mas $1 long lukim o senisim ol samting long lukautbuk bilong yu.',
'watchnologintext'     => 'Yu mas [[Special:UserLogin|login]] long senisim lukautbuk bilong yu.',
'addedwatch'           => 'Igo insait long lukautbuk',
'addedwatchtext'       => "Pes \"[[:\$1]]\" igo insait long [[Special:Watchlist|lukautbuk]] bilong yu nau.
Bai yu lukim ol nupela senis long dispela pes, na pes toktok bilong en, long lukautbuk, 
na dispela pes bai kamap '''strongpela''' long [[Special:RecentChanges|pes bilong ol nupela senis]]
na olsem bai isi long lukim em.

Sapos yu laik rausim dispela pes long lukautbuk bilong yu bihain, paitim \"Pinis long lukautim\" taim yu lukim pes.",
'removedwatch'         => 'Raus pinis long lukautbuk',
'removedwatchtext'     => 'Pes "[[:$1]]" i raus pinis long lukautbuk bilong yu.',
'watch'                => 'Lukautim',
'watchthispage'        => 'Lukautim dispela pes',
'unwatch'              => 'Pinis long lukautim',
'unwatchthispage'      => 'Pinis long lukautim',
'watchlist-details'    => '$1 pes istap long lukautbuk (dispela namba i no kaunim ol pes bilong toktok).',
'wlheader-showupdated' => "* Ol pes i senis pinis bihain long taim yu lukim ol igat nem i '''strongpela'''",

'enotif_reset' => 'Makim olgeta pes olsem mi lukim pinis',

# Contributions
'contributions' => 'Ol senis yusa i wokim',
'mycontris'     => 'Ol senis mi wokim',

# What links here
'whatlinkshere' => 'Ol link ikam long hia',

# Move page
'movepagebtn'     => 'Surikim',
'pagemovedsub'    => 'Pes i surik pinis',
'articleexists'   => 'Wanpela pes wantaim dispela nem i stap pinis, o dispela nem i no stret.
Yu mas painim narapela nem.',
'talkexists'      => "'''Pes bilong buk i surik pinis, tasol pes bilong toktok i no inap surik, bilong wanem wanpela pes bilong toktok istap pinis wantaim dispela nam.  Yu mas pasim wantaim tupela pes bilong toktok yu yet.'''",
'movedto'         => 'i surik i go long',
'movetalk'        => 'Surikim pes bilong toktok wantaim',
'1movedto2'       => '[[$1]] i surik i go long [[$2]] pinis',
'movelogpage'     => 'Buk bilong ol surik',
'movelogpagetext' => 'Hia yumi lukim ol pes i surik pinis.',

# Namespace 8 related
'allmessages' => 'Ol toksave bilong sistem',

# Tooltip help for the actions
'tooltip-ca-nstab-category' => 'Lukim grup',

# Watchlist editor
'watchlistedit-numitems'       => 'Igat {{PLURAL:$1|1 samting|$1 samting}} insait long lukautbuk bilong yu (ol pes bilong toktok i no stap long dispela namba).',
'watchlistedit-noitems'        => 'Nogat wanpela samting long lukautbuk bilong yu.',
'watchlistedit-normal-title'   => 'Senisim lukautbuk',
'watchlistedit-normal-legend'  => 'Rausim ol samting long lukautbuk',
'watchlistedit-normal-explain' => 'Ananit yu lukim ol samting long lukautbuk. Long rausim wanpela samting, makim liklik boxis long sait bilong en, na paitim "Rausim ol samting".  Na tu yu inap [[Special:Watchlist/raw|senisim lukautbuk long wanpela bokis]].',
'watchlistedit-normal-submit'  => 'Rausim ol samting',
'watchlistedit-normal-done'    => '{{PLURAL:$1|Wanpela|$1}} samting i raus pinis long lukautbuk bilong yu:',
'watchlistedit-raw-title'      => 'Senisim lukautbuk long wanpela bokis',
'watchlistedit-raw-legend'     => 'Senisim lukautbuk insait long wanpela bokis',
'watchlistedit-raw-explain'    => 'Ananit yu lukim ol samting long lukautbuk bilong yu insait long wanpela bokis.
	Yu inap putim sampela moa samting igo insait, o rausim sampela ol samting. Putim
	wanpela samting i go long wanwan lain.  Taim yu pinisim ol senis, paitim "Senisim lukautbuk".
	Na tu yu inap [[Special:Watchlist/edit|senisim lukautbuk long planti liklik bokis]].',
'watchlistedit-raw-titles'     => 'Ol samting:',
'watchlistedit-raw-submit'     => 'Senisim lukautbuk',
'watchlistedit-raw-done'       => 'Lukautbuk bilong yu i senis pinis.',
'watchlistedit-raw-added'      => '{{PLURAL:$1|wanpela|$1}} samting igo insait:',
'watchlistedit-raw-removed'    => '{{PLURAL:$1|Wanpela|$1}} samting i raus pinis:',

# Watchlist editing tools
'watchlisttools-view' => 'Lukim ol senis',
'watchlisttools-edit' => 'Lukim na senisim lukautbuk',
'watchlisttools-raw'  => 'Senisim lukautbuk insait long wanpela bokis',

# Special:SpecialPages
'specialpages' => 'Ol sipesol pes',

);

==> mediawiki-1.14.0rc1.tar.gz: mediawiki-1.14.0rc1/languages/messages/MessagesTpi.php <==
<?php
/** Tok Pisin (Tok Pisin)
 *
 * @ingroup Language
 * @file
 *
 * @author Wantok
 * @author Wytukaze
 * @author לערי ריינהארט
 */

$specialPageAliases = array(
	'Userlogin'                 => array( 'Yusa login' ),
	'Userlogout'                => array( 'Yusa logaut' ),
	'CreateAccount'             => array( 'Mekim nupela login' ),
	'Preferences'               => array( 'Ol laik bilong mi' ),
	'Watchlist'                 => array( 'Lukautbuk' ),
	'Recentchanges'             => array( 'Nupela senis' ),
	'Upload'                    => array( 'Salim media fail' ),
	'Randompage'                => array( 'Soim wanpela pes' ),
	'Specialpages'              => array( 'Sipesol pes' ),
	'Contributions'             => array( 'Ol senis bilong yusa' ),
	'Emailuser'                 => array( 'Imel yusa' ),
	'Confirmemail'              => array( 'Orait long imel' ),
	'Whatlinkshere'             => array( 'Ol link ikam long hia' ),
);

$messages = array(
# User preference toggles
'tog-underline'               => 'Putim lain ananit long ol link:',
'tog-highlightbroken'         => 'Soim ol link long ol pes i no stap yet <a href="" class="new">olsem</a> (o: olsem<a href="" class="internal">?</a>).',
'tog-justify'                 => "Soim ol paragraf i pulmapim sipes long lephan i go long raithan (''justify'')",
'tog-hideminor'               => 'Noken soim ol liklik senis insait long ol nupela senis',
'tog-extendwatchlist'         => 'Larim lukautbuk i go longpela long soim olgeta senis',
'tog-usenewrc'                => 'Moa beta stail bilong nupela senis (i nidim JavaScript)',
'tog-numberheadings'          => 'Putim ol namba i go long wanwan hap bilong pes',
'tog-showtoolbar'             => 'Soim ol liklik link long wokim senis kwiktaim (i nidim JavaScript)',
'tog-editondblclick'          => 'Senisim pes taim yu paitim tupela taim kwiktaim (i nidim JavaScript)',
'tog-editsection'             => 'Soim ol [senisim] link long wanwan hap bilong ol pes',
'tog-editsectiononrightclick' => 'Senisim ol hap bilong pes taim yu paitim nem bilong hap<br />wantaim raithan-klik (i nidim Javascript)',
'tog-showtoc'                 => 'Soim ol nem bilong hap insait long liklik bokis, taim igat antap long 3 hap long pes',
'tog-rememberpassword'        => 'Holim nem bilong yusa bilong mi long dispela kompiuta',
'tog-editwidth'               => 'Larim bokis bilong senisim igo bikpela olgeta',
'tog-watchcreations'          => 'Putim ol nupela pes mi wokim long lukautbuk',
'tog-watchdefault'            => 'Putim ol pes mi senisim long lukautbuk bilong mi',
'tog-watchmoves'              => 'Putim ol pes mi surikim long lukautbuk bilong mi',
'tog-watchdeletion'           => 'Putim ol pes mi rausim long lukautbuk bilong mi',
'tog-minordefault'            => 'Makim ol senis mi wokim olsem ol i liklik, sapos mi no makim',
'tog-previewontop'            => 'Soim pes mi senisim (pastaim long raitim) antap long bokis bilong wokim senis',
'tog-previewonfirst'          => 'Soim pes mi senisim pastaim long raitim',
'tog-enotifwatchlistpages'    => 'Salim imel (e-mail) long mi taim wanpela pes mi lukautim i senis',
'tog-shownumberswatching'     => 'Soim hamas yusa i lukautim pes',
'tog-uselivepreview'          => 'Soim ol senis kwiktaim taim mi wokim (i nidim Javascript)',
'tog-watchlisthideown'        => 'Haitim ol senis mi wokim long lukautbuk bilong mi',
'tog-watchlisthidebots'       => 'Haitim ol senis ol bot i wokim long lukautbuk bilong mi',
'tog-watchlisthideminor'      => 'Haitim ol liklik senis long lukautbuk bilong mi',

# Dates
'sunday'    => 'Sande',
'monday'    => 'Mande',
'tuesday'   => 'Tunde',
'wednesday' => 'Trinde',
'thursday'  => 'Fonde',
'friday'    => 'Fraide',
'saturday'  => 'Sarere',
'sun'       => 'San',
'mon'       => 'Man',
'tue'       => 'Tun',
'wed'       => 'Tri',
'thu'       => 'Fon',
'fri'       => 'Frai',
'sat'       => 'Sar',

# Categories related messages
'pagecategories'        => '{{PLURAL:$1|Grup|Ol grup}}',
'category_header'       => 'Ol pes insait long grup "$1"',
'subcategories'         => 'Ol grup insait long grup',
'category-media-header' => 'Ol media (olsem piksa) insait long grup "$1"',
'category-empty'        => "''Dispela grup i no gat wanpela pes o media (olsem piksa) insait long en nau.''",

'newwindow'      => '(bai kamap long nupela windo)',
'cancel'         => 'Toromwe senis',
'qbfind'         => 'Painim',
'qbedit'         => 'Senisim',
'qbspecialpages' => 'Ol sipesol pes',
'mytalk'         => 'Toktok bilong mi',
'navigation'     => 'Ol bikpela pes',

'help'             => 'Halivim mi',
'search'           => 'Painim',
'searchbutton'     => 'Painim',
'history'          => 'Ol senis long dispela pes',
'history_short'    => 'Ol senis',
'edit'             => 'Senisim',
'delete'           => 'Rausim',
'deletethispage'   => 'Rausim dispela pes',
'talkpagelinktext' => 'Toktok',
'talk'             => 'Toktok',
'toolbox'          => 'Sipesol bokis',
'categorypage'     => 'Lukim pes bilong grup',
'otherlanguages'   => 'Long ol narapela tokples',
'jumptonavigation' => 'ol bikpela pes',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Karen afeas',
'currentevents-url'    => 'Project:Karen afeas',
'edithelp'             => 'Halivim mi long pasin bilong wokim senis',
'mainpage'             => 'Fran Pes',
'mainpage-description' => 'Fran Pes',
'portal'               => 'Bung ples',
'portal-url'           => 'Project:Bung ples',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Stori',
'nstab-user'      => 'Pes bilong yusa',
'nstab-media'     => 'Media pes',
'nstab-special'   => 'Sipesol',
'nstab-mediawiki' => 'Toksave',
'nstab-category'  => 'Grup',

# Login and logout pages
'logout'     => 'Logaut',
'userlogout' => 'Logaut',

# Edit pages
'summary'           => 'Liklik toksave bilong senis:',
'subject'           => 'Nem bilong pes (o hap bilong pes):',
'minoredit'         => 'Dispela emi liklik senis',
'watchthis'         => 'Putim dispela pes long lukautbuk bilong mi',
'savearticle'       => 'Raitim pes',
'preview'           => 'Pes wantaim senis (pastaim long raitim)',
'showpreview'       => 'Soim pes wantaim senis (pastaim long raitim)',
'showlivepreview'   => 'Soim senis kwiktaim taim mi wokim (pastaim long raitim)',
'showdiff'          => 'Soim ol senis',
'summary-preview'   => 'Toksave bilong senis bai luk olsem:',
'subject-preview'   => 'Nem bilong pes (o hap bilong pes) bai olsem:',
'copyrightwarning'  => 'Toksave: olgeta senis yu wokim long long {{SITENAME}} bai stap ananit long tokorait $2 (lukim $1 long painimaut moa long dispela). Sapos yu no laikim narapela manmeri long senisim olgeta, o salim dispela i go long ol kainkain hap, noken raitim long hia.<br />
Na tu yu tok tru nau olsem yu raitim dispela yu yet, o yu kisim long wanpela hap we lo i tok olsem i orait long kisim (Tok Inglis: <i>public domain</i>).
<strong>YU NOKEN RAITIM WANPELA SAMTING SAPOS YU NO WOKIM YU YET, O YU KISIM TOKORAIT LONG PUTIM LONG HIA!</strong>',
'copyrightwarning2' => 'Toksave: olgeta senis yu wokim long long {{SITENAME}} bai inap senis o raus long han bilong ol narapela manmeri. Sapos yu no laikim narapela manmeri long senisim olgeta samting yu raitim, o salim dispela i go long ol kainkain hap, noken raitim long hia.<br />
Na tu yu tok tru nau olsem yu raitim dispela yu yet, o yu kisim long wanpela hap we lo i tok olsem i orait long kisim (Tok Inglis: <i>public domain</i>). Lukim $1 long painimaut moa long dispela.<br />
<strong>YU NOKEN RAITIM WANPELA SAMTING IGAT COPYRIGHT LONG EN (NARAPELA MANMERI I RAITIM)!</strong>',
'templatesused'     => 'Dispela pes i yusim ol templet:',

# Preferences page
'mypreferences'   => 'Ol laik bilong mi',
'prefs-edits'     => 'Hamas senis:',
'skin-preview'    => 'pes mi senisim, pastaim long raitim',
'prefs-rc'        => 'Nupela senis',
'prefs-watchlist' => 'Lukautbuk',

# Recent changes
'recentchanges'     => 'Nupela senis',
'rcnote'            => "Ananit yu lukim '''$1 senis''' long '''$2 de''' igo pinis, na i olsem long $3.",
'rc_categories'     => 'Soim ol senis insait long ol dispela grup tasol (raitim wantaim "|" namel long wanwan)',
'rc_categories_any' => 'Olgeta',

# Recent changes linked
'recentchangeslinked' => 'Ol senis klostu',

# Upload
'upload' => 'Salim media fail',

# Random page
'randompage' => 'Soim wanpela pes',

# Miscellaneous special pages
'ncategories'             => '$1 {{PLURAL:$1|grup|grup}}',
'nmembers'                => '$1 {{PLURAL:$1|memba|memba}}',
'uncategorizedpages'      => 'Ol pes i no stap insait long grup',
'uncategorizedcategories' => 'Ol grup i no stap insait long grup',
'uncategorizedimages'     => 'Ol piksa i no stap insait long grup',
'uncategorizedtemplates'  => 'Ol templet i no stap insait long grup',
'unusedcategories'        => 'Ol grup i no gat samting insait long ol',
'unusedimages'            => 'Ol media (olsem piksa) i no gat wanpela pes i soim ol',
'wantedcategories'        => 'Ol grup i no stap yet tasol igat link i kam long ol',
'wantedpages'             => 'Ol pes i no stap yet tasol igat link i kam long ol',
'mostlinked'              => 'Ol pes i gat planti link i kam long ol',
'mostlinkedcategories'    => 'Ol grup igat planti link i kam long ol',
'mostlinkedtemplates'     => 'Ol templet igat planti link i kam long ol',
'mostcategories'          => 'Ol pes bilong buk istap insait long planti grup',
'move'                    => 'Surikim',
'movethispage'            => 'Surikim dispela pes',
'unusedcategoriestext'    => 'Ol dispela grup istap yet, tasol i no gat wanpela pes o grup i stap insait long ol.',

# Special:AllPages
'allpages' => 'Olgeta pes',

# Special:Categories
'categories'         => 'Ol grup',
'categoriespagetext' => 'Ol dispela grup istap.',

# Watchlist
'watchlist'            => 'Lukautbuk bilong mi',
'mywatchlist'          => 'Lukautbuk bilong mi',
'watchlistfor'         => "(bilong '''$1''')",
'nowatchlist'          => 'Nogat wanpela samting istap long lukautbuk bilong yu.',
'watchlistanontext'    => 'Yu mas $1 long lukim o senisim ol samting long lukautbuk bilong yu.',
'watchnologintext'     => 'Yu mas [[Special:UserLogin|login]] long senisim lukautbuk bilong yu.',
'addedwatch'           => 'Igo insait long lukautbuk',
'addedwatchtext'       => "Pes \"[[:\$1]]\" igo insait long [[Special:Watchlist|lukautbuk]] bilong yu nau.
Bai yu lukim ol nupela senis long dispela pes, na pes toktok bilong en, long lukautbuk, 
na dispela pes bai kamap '''strongpela''' long [[Special:RecentChanges|pes bilong ol nupela senis]]
na olsem bai isi long lukim em.

Sapos yu laik rausim dispela pes long lukautbuk bilong yu bihain, paitim \"Pinis long lukautim\" taim yu lukim pes.",
'removedwatch'         => 'Raus pinis long lukautbuk',
'removedwatchtext'     => 'Pes "[[:$1]]" i raus pinis long lukautbuk bilong yu.',
'watch'                => 'Lukautim',
'watchthispage'        => 'Lukautim dispela pes',
'unwatch'              => 'Pinis long lukautim',
'unwatchthispage'      => 'Pinis long lukautim',
'watchlist-details'    => '$1 pes istap long lukautbuk (dispela namba i no kaunim ol pes bilong toktok).',
'wlheader-showupdated' => "* Ol pes i senis pinis bihain long taim yu lukim ol igat nem i '''strongpela'''",

'enotif_reset' => 'Makim olgeta pes olsem mi lukim pinis',

# Protect
'prot_1movedto2' => '[[$1]] i surik i go long [[$2]] pinis',

# Contributions
'contributions' => 'Ol senis yusa i wokim',
'mycontris'     => 'Ol senis mi wokim',

# What links here
'whatlinkshere' => 'Ol link ikam long hia',

# Move page
'movepagebtn'     => 'Surikim',
'pagemovedsub'    => 'Pes i surik pinis',
'articleexists'   => 'Wanpela pes wantaim dispela nem i stap pinis, o dispela nem i no stret.
Yu mas painim narapela nem.',
'talkexists'      => "'''Pes bilong buk i surik pinis, tasol pes bilong toktok i no inap surik, bilong wanem wanpela pes bilong toktok istap pinis wantaim dispela nam.  Yu mas pasim wantaim tupela pes bilong toktok yu yet.'''",
'movedto'         => 'i surik i go long',
'movetalk'        => 'Surikim pes bilong toktok wantaim',
'1movedto2'       => '[[$1]] i surik i go long [[$2]] pinis',
'movelogpage'     => 'Buk bilong ol surik',
'movelogpagetext' => 'Hia yumi lukim ol pes i surik pinis.',

# Namespace 8 related
'allmessages' => 'Ol toksave bilong sistem',

# Tooltip help for the actions
'tooltip-ca-nstab-category' => 'Lukim grup',

# Watchlist editor
'watchlistedit-numitems'       => 'Igat {{PLURAL:$1|1 samting|$1 samting}} insait long lukautbuk bilong yu (ol pes bilong toktok i no stap long dispela namba).',
'watchlistedit-noitems'        => 'Nogat wanpela samting long lukautbuk bilong yu.',
'watchlistedit-normal-title'   => 'Senisim lukautbuk',
'watchlistedit-normal-legend'  => 'Rausim ol samting long lukautbuk',
'watchlistedit-normal-explain' => 'Ananit yu lukim ol samting long lukautbuk. Long rausim wanpela samting, makim liklik boxis long sait bilong en, na paitim "Rausim ol samting".  Na tu yu inap [[Special:Watchlist/raw|senisim lukautbuk long wanpela bokis]].',
'watchlistedit-normal-submit'  => 'Rausim ol samting',
'watchlistedit-normal-done'    => '{{PLURAL:$1|Wanpela|$1}} samting i raus pinis long lukautbuk bilong yu:',
'watchlistedit-raw-title'      => 'Senisim lukautbuk long wanpela bokis',
'watchlistedit-raw-legend'     => 'Senisim lukautbuk insait long wanpela bokis',
'watchlistedit-raw-explain'    => 'Ananit yu lukim ol samting long lukautbuk bilong yu insait long wanpela bokis.
	Yu inap putim sampela moa samting igo insait, o rausim sampela ol samting. Putim
	wanpela samting i go long wanwan lain.  Taim yu pinisim ol senis, paitim "Senisim lukautbuk".
	Na tu yu inap [[Special:Watchlist/edit|senisim lukautbuk long planti liklik bokis]].',
'watchlistedit-raw-titles'     => 'Ol samting:',
'watchlistedit-raw-submit'     => 'Senisim lukautbuk',
'watchlistedit-raw-done'       => 'Lukautbuk bilong yu i senis pinis.',
'watchlistedit-raw-added'      => '{{PLURAL:$1|wanpela|$1}} samting igo insait:',
'watchlistedit-raw-removed'    => '{{PLURAL:$1|Wanpela|$1}} samting i raus pinis:',

# Watchlist editing tools
'watchlisttools-view' => 'Lukim ol senis',
'watchlisttools-edit' => 'Lukim na senisim lukautbuk',
'watchlisttools-raw'  => 'Senisim lukautbuk insait long wanpela bokis',

# Special:SpecialPages
'specialpages' => 'Ol sipesol pes',

);
